@@ -25,7 +25,7 @@ class Function:
             # FIX: arg1, arg2, optarg1=value, ...
             self.optional_arguments = optional_arguments
 
-        bang = '!' if overwrite else ''
+        bang = "!" if overwrite else ""
 
         # FIX - Spacing to the left
         command = f"""function{bang} {self.name}({arguments})
@@ -33,3 +33,8 @@ class Function:
 
         """.strip()
         vim.command(command)
+
+    def __call__(self, *args, **kwargs):
+        raise NotImplementedError(
+            "This interface has not yet been implemented."
+        )
